@@ -50,10 +50,10 @@ autodoc_member_order = "bysource"
 autosectionlabel_prefix_document = True
 
 extlinks = {
-    "issue": ("https://github.com/pypa/virtualenv/issues/%s", "#"),
-    "pull": ("https://github.com/pypa/virtualenv/pull/%s", "PR #"),
-    "user": ("https://github.com/%s", "@"),
-    "pypi": ("https://pypi.org/project/%s", ""),
+    "issue": ("https://github.com/pypa/virtualenv/issues/%s", "#%s"),
+    "pull": ("https://github.com/pypa/virtualenv/pull/%s", "PR #%s"),
+    "user": ("https://github.com/%s", "@%s"),
+    "pypi": ("https://pypi.org/project/%s", "%s"),
 }
 
 
@@ -78,9 +78,9 @@ def setup(app):
     if cli_interface_doctree.exists():
         cli_interface_doctree.unlink()
 
-    HERE = Path(__file__).parent
-    if str(HERE) not in sys.path:
-        sys.path.append(str(HERE))
+    here = Path(__file__).parent
+    if str(here) not in sys.path:
+        sys.path.append(str(here))
 
     # noinspection PyUnresolvedReferences
     from render_cli import CliTable, literal_data
