@@ -7,6 +7,8 @@ def test_csh(activation_tester_class, activation_tester):
             super().__init__(CShellActivator, session, "csh", "activate.csh", "csh")
 
         def print_prompt(self):
-            return "echo 'source \"$VIRTUAL_ENV/bin/activate.csh\"; echo $prompt' | csh -i"
+            # Original csh doesn't print the last newline,
+            # breaking the test; hence the trailing echo.
+            return "echo 'source \"$VIRTUAL_ENV/bin/activate.csh\"; echo $prompt' | csh -i ; echo"
 
     activation_tester(Csh)
